@@ -26,10 +26,10 @@ class OrganizationActivity(DataClassJsonMixin):
     """組織ID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     created_datetime: str
-    """"""
+    """作成日時"""
 
-    storage_usage_bytes: float
-    """"""
+    storage_usage_bytes: int
+    """Annofabストレージの使用量[バイト]"""
 
 
 @dataclass
@@ -40,19 +40,19 @@ class Organization(DataClassJsonMixin):
     """組織ID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     organization_name: str
-    """"""
+    """組織名。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     email: str
-    """"""
+    """メールアドレス"""
 
     price_plan: PricePlan
     """"""
 
     summary: Dict[str, Any]
-    """"""
+    """廃止予定のプロパティです。常に中身は空です。 """
 
     created_datetime: str
-    """"""
+    """作成日時"""
 
     updated_datetime: str
-    """"""
+    """更新日時"""
